@@ -5,6 +5,13 @@ class TimeClass:
     def __init__(self) -> None:
         pass
 
+    def localdate(self):
+        '''
+        获取格式化的当前日期
+        return {str} 示例：2000-12-12
+        '''
+        return time.strftime('%Y-%m-%d', time.localtime())
+
     def localtime(self):
         '''
         获取格式化的当前时间
